@@ -14,23 +14,13 @@ data(snp_input)
 dim(snp_input)
 data(exercise_input)
 dim(exercise_input)
-#We only included 10% of the excercise data from the paper 
-#due to storage space limit.
-
-#Each matrix contains two columns of p-values for candidate mediators.
-#Column 1 is the p-value of testing if an exposure  is associated with 
-#the mediator (alpha!=0). 
-#Column 2 is the p-value of testing if a mediator is associated with 
-#the outcome adjusted for the exposure (beta!=0) 
-
 
 
 ###################################################
 ### code chunk number 3: input_pvalues
 ###################################################
 input_pvalues <- snp_input
-#To save time for the illustration, we use 10% of rows; to reproduce the 
-# figure in the paper, please don't run the following line
+
 input_pvalues=input_pvalues[sample(1:nrow(input_pvalues),
                   size=ceiling(nrow(input_pvalues)/10)),]
 
@@ -38,30 +28,34 @@ input_pvalues=input_pvalues[sample(1:nrow(input_pvalues),
 ###################################################
 ### code chunk number 4: nullprop
 ###################################################
-nullprop <- nullestimation(input_pvalues,lambda=0.5)
+nullprop <- null_estimation(input_pvalues,lambda=0.5)
+nullprop
 
 
 ###################################################
 ### code chunk number 5: pnull1
 ###################################################
 pnull1<-adjust_quantile(nullprop$alpha00,nullprop$alpha01,nullprop$alpha10,
-nullprop$alpha1,nullprop$alpha2,input_pvalues,method=1)
+                        nullprop$alpha1,nullprop$alpha2,input_pvalues,exact=1)
 
 
 ###################################################
-### code chunk number 6: fdr
-###################################################
-fdr <- fdrest(nullprop$alpha00,nullprop$alpha01,nullprop$alpha10,
-nullprop$alpha1,nullprop$alpha2,input_pvalues,method=0)
-
-
-###################################################
-### code chunk number 7: plot_snp
+### code chunk number 6: plot_snp
 ###################################################
 pmax <- apply(input_pvalues,1,max)
 correct_qqplot(pmax, pnull1)
 
 
+###################################################
+### code chunk number 7: fdr
+###################################################
+efdr <- fdr_est(nullprop$alpha00,nullprop$alpha01,nullprop$alpha10,
+                nullprop$alpha1,nullprop$alpha2,input_pvalues,exact=0)
+
+plot(pmax[order(pmax)],efdr[order(pmax)],type="l",ylim=c(0,1),
+     xlab="p-max",ylab="Estimated FDR")
+
+
 ###################################################
 ### code chunk number 8: input_pvalues
 ###################################################
@@ -74,21 +68,21 @@ input_pvalues=input_pvalues[sample(1:nrow(input_pvalues),
 ###################################################
 ### code chunk number 9: nullprop
 ###################################################
-nullprop <- nullestimation(input_pvalues,lambda=0.5)
+nullprop <- null_estimation(input_pvalues,lambda=0.5)
 
 
 ###################################################
 ### code chunk number 10: pnull
 ###################################################
 pnull<-adjust_quantile(nullprop$alpha00,nullprop$alpha01,nullprop$alpha10,
-nullprop$alpha1,nullprop$alpha2,input_pvalues,method=0)
+nullprop$alpha1,nullprop$alpha2,input_pvalues,exact=0)
 
 
 ###################################################
 ### code chunk number 11: pnull1
 ###################################################
 pnull1<-adjust_quantile(nullprop$alpha00,nullprop$alpha01,nullprop$alpha10,
-nullprop$alpha1,nullprop$alpha2,input_pvalues,method=1)
+nullprop$alpha1,nullprop$alpha2,input_pvalues,exact=1)
 
 
 ###################################################
